##  Creating Free Draw Diagrams
To begin creating diagrams in the Free Draw, log in to your workspace and follow the following steps:
  1. Navigate to the Diagrams section by clicking on the Diagrams tab from the top navigation bar.
  2. Click on New Diagram button to open the panel of available diagram editors.
  3. Select Free Draw from the available diagram types.
  4. Provide a name and description. Here, you can also set read and write permissions, and choose whether or not labels and view colors should automatically update based on changes in the inventory.
  5. Click Save Diagram to open the editor and start working on the diagrams.

![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27440fe47a441014b7c6b761fd1cbefd_LowRes.gif)
**Tip**
To prevent accidental data loss, changes to the diagram are saved automatically in real time. If you accidentally close the window without explicitly saving a diagram, the next time you open it, you are prompted whether to discard the previous changes or continue editing from where you left off.
To manage the Diagrams better and group them into classifications, users with Admin rights can utilize the Collections feature. This feature introduces individual categories among Reports and Diagrams. Check out the [Collections](https://help.sap.com/docs/leanix/ea/collections?locale=en-US&state=PRODUCTION&version=CLOUD "Use collections to arrange dashboards, reports, and diagrams into custom groups.") page to learn more on how to manage these categories.
**Tip**
You can save time by importing architecture templates and example diagrams from [draw.io![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.drawio.com%2Fexample-diagrams "https://www.drawio.com/example-diagrams") to kickstart your project.
